
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Andy
Armstrong
Brian
CIDR
Gottreu
IPv4
IPv6
Inc
Message
Net
Palmquist
Robert
Rothenberg
Set
Stig
Systems
andy
gottreu
lib
masse
rrwo
stigtsp
superset
